<?php

/**
 * @file rules integration for the fb_event module
 *
 */



/**
 * Rules events
 */
 
/**
 * Implements hook_rules_event_info().
 */
function fb_event_rules_event_info() {
  return array(
    'fb_event_rsvp' => array(
      'label' => t('Facebook event RSVP changed'),
      'group' => 'Facebook event',
      'variables' => array(
        'event_node' => array(
          'type' => 'node',
          'label' => t('Event node'),
        ),
        'event_id' => array(
          'type' => 'text',
          'label' => t('Event ID'),
        ),
        'rsvp_user' => array(
          'type' => 'user',
          'label' => t('RSVP user'),
        ),
        'fb_user_id' => array(
          'type' => 'text',
          'label' => t('Facebook user ID'),
        ),
        'rsvp_status' => array(
          'type' => 'text',
          'label' => t('RSVP status'),
        ),
        'rsvp_old_status' => array(
          'type' => 'text',
          'label' => t('RSVP old status'),
        ),
      ),
    ),
  );
}


/**
 * Rules Conditions
 */

/**
 * Implementation of hook_rules_condition_info().
 */
function fb_event_rules_condition_info() {
  return array (
    'fb_event_rules_compare_rsvp' => array(
      'label' => t('Facebook event compare two rsvp statuses'),
      'parameter' => array(
        'rsvp' => array('type' => 'text', 'label' => t('RSVP status 1')),
        'rsvp2' => array(
          'type' => 'list<text>',
          'label' => t('RSVP status 2'),
          'options list' => 'fb_event_get_status_options',
        ),
      ),
      'group' => 'Facebook event',
    ),
    'fb_event_rules_user_has_rsvp' => array(
      'label' => t('Facebook event user has rsvp status'),
      'parameter' => array(
        'user' => array('type' => 'user', 'label' => t('User')),
        'node' => array('type' => 'node', 'label' => t('Event node')),
        'rsvp' => array(
          'type' => 'list<text>',
          'label' => t('RSVP status'),
          'options list' => 'fb_event_get_status_options',
        ),
      ),
      'group' => 'Facebook event',
    ),
  );
}

/**
 * Rule Condition: fb_event_has_rsvp
 */
function fb_event_rules_compare_rsvp($rsvp, $rsvp2, $settings) {
  
  foreach($rsvp2 as $status){
    if ($rsvp == $status){
      return TRUE;
    }
  }
  return FALSE;
  
}


/**
 * Rule Condition: fb_event_has_rsvp
 */
function fb_event_rules_user_has_rsvp($user, $node, $rsvp, $settings) {
  $statuses = $rsvp;
  
  if ( module_exists('fb_user') ) {
    $fbuid = fb_get_fbu($user->uid);
  } else if ( module_exists('fbconnect') ) {
	  $fbuid = _get_user_fbuid($user->uid);
  }
  
  if (!isset($fbuid) || 
      !isset($node->field_fbeid['und'][0]['value']) || 
      empty($node->field_fbeid['und'][0]['value']) ) {
      
    return FALSE;
  }
  
  $fbeid = $node->field_fbeid['und'][0]['value'];
  
  $rsvp = fb_event_get_event_rsvp($fbeid, $fbuid);
  
  foreach($statuses as $status){
    if ($rsvp == $status){
      return TRUE;
    }
  }
  return FALSE;
  
}

